@@ -195,7 +195,7 @@ def disassemble(aCode):
     pc = 0
     res = []
     while pc < codelen:
-        opcode = ord(aCode[pc:pc+1])
+        opcode = byteord(aCode[pc:pc+1])
         if opcode > len(aCode_info):
             instr = aCode_info[0]
         else:
@@ -203,7 +203,7 @@ def disassemble(aCode):
         pc += 1
         if instr[1] != 0 and pc >= codelen : return res
         if instr[1] == -1:
-            count = ord(aCode[pc])
+            count = byteord(aCode[pc])
             fmt = "%dB" % count
             pc += 1
         elif instr[1] == 0:
@@ -230,7 +230,7 @@ def assemble(instrs):
         if m.group(2):
             if parmfmt == 0:
                 continue
-            parms = map(int, re.split(",\s*", m.group(2)))
+            parms = [int(x) for x in re.split(",\s*", m.group(2))]
             if parmfmt == -1:
                 l = len(parms)
                 res.append(struct.pack(("%dB" % (l+1)), l, *parms))
@@ -727,9 +727,6 @@ class Pass(object):
                 oConstraints[i] = oConstraints[i+1]
         self.ruleConstraints = [(data[s:e] if (e-s > 1) else "") for (s,e) in zip(oConstraints, oConstraints[1:])]
         data = data[oConstraints[-1]:]
-        for i in range(len(oActions)-2,-1,-1):
-            if oActions[i] == 0:
-                oActions[i] = oActions[i+1]
         self.actions = [(data[s:e] if (e-s > 1) else "") for (s,e) in zip(oActions, oActions[1:])]
         data = data[oActions[-1]:]
         # not using debug
@@ -737,8 +734,8 @@ class Pass(object):
     def compile(self, ttFont, base, version=2.0):
         # build it all up backwards
         oActions = reduce(lambda a, x: (a[0]+len(x), a[1]+[a[0]]), self.actions + [""], (0, []))[1]
-        oConstraints = reduce(lambda a, x: (a[0]+len(x), a[1]+[a[0]]), self.ruleConstraints + [""], (0, []))[1]
-        constraintCode = "".join(self.ruleConstraints)
+        oConstraints = reduce(lambda a, x: (a[0]+len(x), a[1]+[a[0]]), self.ruleConstraints + [""], (1, []))[1]
+        constraintCode = "\000" + "".join(self.ruleConstraints)
         transes = []
         for t in self.stateTrans:
             t.byteswap()
