@@ -2,6 +2,7 @@ from __future__ import print_function, division, absolute_import
 from fontTools.misc import xmlWriter
 from fontTools.misc.py23 import *
 from fontTools.misc.loggingTools import deprecateArgument
+from fontTools.ttLib import TTLibError
 from fontTools.ttLib.sfnt import SFNTReader, SFNTWriter
 import os
 import logging
@@ -493,7 +494,10 @@ class TTFont(object):
 		# glyphs (eg. ligatures or alternates) may not be reachable via cmap,
 		# this naming table will usually not cover all glyphs in the font.
 		# If the font has no Unicode cmap table, reversecmap will be empty.
-		reversecmap = self['cmap'].buildReversed()
+		if 'cmap' in self:
+			reversecmap = self['cmap'].buildReversed()
+		else:
+			reversecmap = {}
 		useCount = {}
 		for i in range(numGlyphs):
 			tempName = glyphOrder[i]
@@ -507,14 +511,15 @@ class TTFont(object):
 					glyphName = "%s.alt%d" % (glyphName, numUses - 1)
 				glyphOrder[i] = glyphName
 
-		# Delete the temporary cmap table from the cache, so it can
-		# be parsed again with the right names.
-		del self.tables['cmap']
-		self.glyphOrder = glyphOrder
-		if cmapLoading:
-			# restore partially loaded cmap, so it can continue loading
-			# using the proper names.
-			self.tables['cmap'] = cmapLoading
+		if 'cmap' in self:
+			# Delete the temporary cmap table from the cache, so it can
+			# be parsed again with the right names.
+			del self.tables['cmap']
+			self.glyphOrder = glyphOrder
+			if cmapLoading:
+				# restore partially loaded cmap, so it can continue loading
+				# using the proper names.
+				self.tables['cmap'] = cmapLoading
 
 	@staticmethod
 	def _makeGlyphName(codepoint):
@@ -715,6 +720,9 @@ class _TTGlyphSet(object):
 		return self._glyphType(
 			self, self._glyphs[glyphName], horizontalMetrics, verticalMetrics)
 
+	def __len__(self):
+		return len(self._glyphs)
+
 	def get(self, glyphName, default=None):
 		try:
 			return self[glyphName]
